﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIokAYJKoZIhvcNAQcCoIIogTCCKH0CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB5mT/HBF+ApGFF
# NurlQsK+/gKFs6a98ziX+/GaLDsVJqCCDfAwggZuMIIEVqADAgECAhMzAAACjX5H
# w4J+BRoqAAAAAAKNMA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjExMDE0MTg0NTE0WhcNMjIxMDEzMTg0NTE0WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAz6djBvGQeEXcJBPGF9t+
# rTJj2I2Z/6+mxfIev5bXiw0pbZWY3jzDBS20WCQSVlZcNHv8tWspGM3XBRbL9vOw
# VOjJ0yyIjM1PUdSK8x95P9zKSlM39xUv9m+8aueEl5dASfXGucY2pbemzQ2NBAs9
# 3Z+8jLVj9gAiH2vb50eRiP5WOYS2/2/uvaNu2SVbDo4WA7CQHx8YD7XlCKfL7V0T
# la8i0uP8Mas+YJbPgxWB8bjae0TjzUUvLhTvisEQO1o1qE609RJLzJONR40iCLd5
# OTOdK162eOCv4GfQijgqEyqTADtxq/nDGU5FNT85N0zo9UmvDo0oLojO0qp46OUW
# zbqHVzl4FjpkohsHA2QNC5Kr8/naA6OxPOH+z70k/BtfOv+mWsBchdmHXvwdOuyv
# mA/2Jo9dYgwO+UwXDnixpkHrweH4PVeIAqY69y3h612Ty/zCUn3o7ePxLaiiZJ2p
# wAt7JxzuFWeknyPqEVVb2FcVGpJv1VifXxwy7m7da8iRAgMBAAGjggF+MIIBejAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUHgevMUhF
# qAngfzHomhzHqKBeXs4wUAYDVR0RBEkwR6RFMEMxKTAnBgNVBAsTIE1pY3Jvc29m
# dCBPcGVyYXRpb25zIFB1ZXJ0byBSaWNvMRYwFAYDVQQFEw00NjQyMjMrNDY4NjI2
# MB8GA1UdIwQYMBaAFEhuZOVQBdOCqhc3NyK1bajKdQKVMFQGA1UdHwRNMEswSaBH
# oEWGQ2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY0NvZFNp
# Z1BDQTIwMTFfMjAxMS0wNy0wOC5jcmwwYQYIKwYBBQUHAQEEVTBTMFEGCCsGAQUF
# BzAChkVodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NlcnRzL01pY0Nv
# ZFNpZ1BDQTIwMTFfMjAxMS0wNy0wOC5jcnQwDAYDVR0TAQH/BAIwADANBgkqhkiG
# 9w0BAQwFAAOCAgEAHiqaRgbuQorcDr+hk14g/0mE2DtJf5WdpxAa7AgdbZPEgI5t
# VRWHs+ryb7Eb0RyjhaXwCgCuE5aencgxYWIX6/EYPvNomkbvuTEVcN7CwDw+d6HC
# cx8erpOWIjn/rn4VkHgp/kTLXqzZCTqdNKr9uyBPnvZoKRT2E93lZe6SFF+5A6da
# fqVFZESFyoBF64WaKTlgP6GAlmCjewINzTWFUSA4h3CCNcwQ0AusCBpCWn9AVFf4
# MxGlb3p7IWgoVFaJG50GG1Kp/0j5aZODMr1BK2BPyaeeNpjvR/z91yqzSe/jCtZv
# jfzBPXF13IitBcyc5thkKpvskM1M99Gkql8DKTCFGYAkMO8Of/M2aXP+9xpTj5Yu
# 0FXbOnKTihVxnMmAxaAaXeB2Dz580BwuhDB9GqT7Bglxy74hfyVHSH4LKCiY8oAu
# bFJvZKEmxTcFdd3oTXfk+AKQ+y/Hee3J6ittwCyFQ4hqolqZM51aQ1/lf3tChMMS
# 4+xLa0jMjea6e+0NnXifKTJiN/h5fw1HqkDA4SAytZDXi1pIqroxpc25wZqoLMXD
# 8v7inXXmJls6jr34646FtU0Ha0hmN4pgTtAopT6UB3OBlRpzJr4yDUq7ed0Z28MH
# whPvflzedTfwtXxi263mPG9qIDWibcM26Z9U0AhMeCckXynvHUPMgDk1rHYwggd6
# MIIFYqADAgECAgphDpDSAAAAAAADMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQg
# Um9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAxMTAeFw0xMTA3MDgyMDU5MDla
# Fw0yNjA3MDgyMTA5MDlaMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
# dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
# YXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTEw
# ggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCr8PpyEBwurdhuqoIQTTS6
# 8rZYIZ9CGypr6VpQqrgGOBoESbp/wwwe3TdrxhLYC/A4wpkGsMg51QEUMULTiQ15
# ZId+lGAkbK+eSZzpaF7S35tTsgosw6/ZqSuuegmv15ZZymAaBelmdugyUiYSL+er
# CFDPs0S3XdjELgN1q2jzy23zOlyhFvRGuuA4ZKxuZDV4pqBjDy3TQJP4494HDdVc
# eaVJKecNvqATd76UPe/74ytaEB9NViiienLgEjq3SV7Y7e1DkYPZe7J7hhvZPrGM
# XeiJT4Qa8qEvWeSQOy2uM1jFtz7+MtOzAz2xsq+SOH7SnYAs9U5WkSE1JcM5bmR/
# U7qcD60ZI4TL9LoDho33X/DQUr+MlIe8wCF0JV8YKLbMJyg4JZg5SjbPfLGSrhwj
# p6lm7GEfauEoSZ1fiOIlXdMhSz5SxLVXPyQD8NF6Wy/VI+NwXQ9RRnez+ADhvKwC
# gl/bwBWzvRvUVUvnOaEP6SNJvBi4RHxF5MHDcnrgcuck379GmcXvwhxX24ON7E1J
# MKerjt/sW5+v/N2wZuLBl4F77dbtS+dJKacTKKanfWeA5opieF+yL4TXV5xcv3co
# KPHtbcMojyyPQDdPweGFRInECUzF1KVDL3SV9274eCBYLBNdYJWaPk8zhNqwiBfe
# nk70lrC8RqBsmNLg1oiMCwIDAQABo4IB7TCCAekwEAYJKwYBBAGCNxUBBAMCAQAw
# HQYDVR0OBBYEFEhuZOVQBdOCqhc3NyK1bajKdQKVMBkGCSsGAQQBgjcUAgQMHgoA
# UwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQY
# MBaAFHItOgIxkEO5FAVO4eqnxzHRI4k0MFoGA1UdHwRTMFEwT6BNoEuGSWh0dHA6
# Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1
# dDIwMTFfMjAxMV8wM18yMi5jcmwwXgYIKwYBBQUHAQEEUjBQME4GCCsGAQUFBzAC
# hkJodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1
# dDIwMTFfMjAxMV8wM18yMi5jcnQwgZ8GA1UdIASBlzCBlDCBkQYJKwYBBAGCNy4D
# MIGDMD8GCCsGAQUFBwIBFjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3Bz
# L2RvY3MvcHJpbWFyeWNwcy5odG0wQAYIKwYBBQUHAgIwNB4yIB0ATABlAGcAYQBs
# AF8AcABvAGwAaQBjAHkAXwBzAHQAYQB0AGUAbQBlAG4AdAAuIB0wDQYJKoZIhvcN
# AQELBQADggIBAGfyhqWY4FR5Gi7T2HRnIpsLlhHhY5KZQpZ90nkMkMFlXy4sPvjD
# ctFtg/6+P+gKyju/R6mj82nbY78iNaWXXWWEkH2LRlBV2AySfNIaSxzzPEKLUtCw
# /WvjPgcuKZvmPRul1LUdd5Q54ulkyUQ9eHoj8xN9ppB0g430yyYCRirCihC7pKkF
# DJvtaPpoLpWgKj8qa1hJYx8JaW5amJbkg/TAj/NGK978O9C9Ne9uJa7lryft0N3z
# Dq+ZKJeYTQ49C/IIidYfwzIY4vDFLc5bnrRJOQrGCsLGra7lstnbFYhRRVg4MnEn
# Gn+x9Cf43iw6IGmYslmJaG5vp7d0w0AFBqYBKig+gj8TTWYLwLNN9eGPfxxvFX1F
# p3blQCplo8NdUmKGwx1jNpeG39rz+PIWoZon4c2ll9DuXWNB41sHnIc+BncG0Qax
# dR8UvmFhtfDcxhsEvt9Bxw4o7t5lL+yX9qFcltgA1qFGvVnzl6UJS0gQmYAf0AAp
# xbGbpT9Fdx41xtKiop96eiL6SJUfq/tHI4D1nvi/a7dLl+LrdXga7Oo3mXkYS//W
# syNodeav+vyL6wuA6mk7r/ww7QRMjt/fdW1jkT3RnVZOT7+AVyKheBEyIXrvQQqx
# P/uozKRdwaGIm1dxVk5IRcBCyZt2WwqASGv9eZ/BvW1taslScxMNelDNMYIZ9jCC
# GfICAQEwgZUwfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEo
# MCYGA1UEAxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAxMQITMwAAAo1+
# R8OCfgUaKgAAAAACjTANBglghkgBZQMEAgEFAKCBrjAZBgkqhkiG9w0BCQMxDAYK
# KwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAvBgkqhkiG
# 9w0BCQQxIgQgu0R4wRR6xdzJye8AHTQLWb7VeQRxQGN+E0g3YhmB+RkwQgYKKwYB
# BAGCNwIBDDE0MDKgFIASAE0AaQBjAHIAbwBzAG8AZgB0oRqAGGh0dHA6Ly93d3cu
# bWljcm9zb2Z0LmNvbTANBgkqhkiG9w0BAQEFAASCAYAOSOcsxs9dtuVb7T9LjKwO
# 8zq5fqQ17qLBncelpQ6mc+P1BqqMTaJb6A0h0m29u4TJwZzmOYhmcnj//EBbVG9g
# DUNGkWKNfww94E75OPTGqFTOJATFZWmmWt3bmOQsZxeSBRDC8W6E2+Cp0QjmIb8b
# QQTgHA8HCDhVa+8xKDobmNrYEjGJucbkbpKhO8sxgaQeyY3Q8JZUWs0GDhDamGAS
# awf34KNj+ISZlJxbocGHpffEUII179iTw438+hdnOuKgxwdxGQqhBuBUAT96h21R
# YxPnXEyuC390jetK1VusUJhHIFV5Hp9qhiDv8e4XTAX0MWTR/09ebR1eCWZv1MyT
# YZW9iWl89ckfLpDT2Tw6NL7IPbh+6u/GIBa7DRWbZXjy55DZU4sEIZBFd6MTllGP
# zla9Ghr/KSSP/z1NOpVf+jcQyRKy/r2hnZxISPAPOX0qsbWFPCug2zrkeD42eBVb
# 5DSQs5UO04azFublXsTtTA+zvvA72VGA4kyP4N+VUSyhghcAMIIW/AYKKwYBBAGC
# NwMDATGCFuwwghboBgkqhkiG9w0BBwKgghbZMIIW1QIBAzEPMA0GCWCGSAFlAwQC
# AQUAMIIBUQYLKoZIhvcNAQkQAQSgggFABIIBPDCCATgCAQEGCisGAQQBhFkKAwEw
# MTANBglghkgBZQMEAgEFAAQge0ikU6sXFUe4tLWUn7OUkzxwvqFCi89QPcEviI0x
# DQICBmIWX3d8RRgTMjAyMjAzMTgyMzUxMTEuMDE5WjAEgAIB9KCB0KSBzTCByjEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWlj
# cm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEmMCQGA1UECxMdVGhhbGVzIFRTUyBF
# U046RTVBNi1FMjdDLTU5MkUxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1w
# IFNlcnZpY2WgghFXMIIHDDCCBPSgAwIBAgITMwAAAZW3/A3W4zcxJQABAAABlTAN
# BgkqhkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
# bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
# aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0y
# MTEyMDIxOTA1MTJaFw0yMzAyMjgxOTA1MTJaMIHKMQswCQYDVQQGEwJVUzETMBEG
# A1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
# cm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBP
# cGVyYXRpb25zMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpFNUE2LUUyN0MtNTky
# RTElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCCAiIwDQYJ
# KoZIhvcNAQEBBQADggIPADCCAgoCggIBAJ9tQQxntks7P1qhEJ4kviGFP1DwlkHb
# FpWUw0K3dvCFxMjkYs+u3Z73cMCyaWo7PDVwWI8+DpLmwsJfPstttRCkuFrxLi/a
# pxwy1OiQRoNBL5AkSucCyXpVKZG8DLSeWP4L89pm4tvc7NjQBHDtR4JkunJY88f6
# Tkx1iPo1QNM2hepvNAcK4+z5+AiiujnLcMeg7TvuDoivZMcjHXJ9UUS3nMNwU85g
# yDjIGLgDpdzeGb21nrDzj2cG9UrCblgAt8ffL9/efguc3rVvXDMDHdkJmN/XdQpu
# kTunoNgmsdEH/6nAWMb31PAcfq5fMN5lPr+vqofsAAHCfx+lhzVOaV4VjxhG5XPO
# On1WQ8dXxXO/MsvtAraS155csv9jiW+MvqHPI6YT7UtUPeURtiGjXMK34XttT4Wm
# PIF9MLiL/Aeym1vbXxiVuRC3WLUHqWWYnBUXAItfuDFDjxAgZRpwzLySnX7NzNj5
# LGWloSA2ZCR9zWto+H3Lmwxrpfjz7HQrsHw6oOhdxOIQIiMl63HC24GVCx4nTkdF
# +Kx+AWbT2Qbu90cSjc1tS4wwEWKRzhug31R+bSJSGr8m2pXQrCu/0K/drIOB03AR
# aIvZrrkicRZKlFNh+wJDTd6oSHkDevBX8p9QVyK34Os/71VwOmNZGwKiRm/i2Cfm
# oBc0y0drw2KpAgMBAAGjggE2MIIBMjAdBgNVHQ4EFgQUq5fTYgIUV1eCtwIGYMl8
# fm/8qRcwHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYDVR0fBFgw
# VjBUoFKgUIZOaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWlj
# cm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3JsMGwGCCsGAQUF
# BwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAxMCgx
# KS5jcnQwDAYDVR0TAQH/BAIwADATBgNVHSUEDDAKBggrBgEFBQcDCDANBgkqhkiG
# 9w0BAQsFAAOCAgEA4LM23h8n6M69C6rQi2ffshmtg0EazACL4gAUzdgYr/AZCUSd
# yCOY0G5pz3lbZ8AvrG0VV8x+R6pIswuqiJ1WxT0GbgMQGNpY05P25f+1xiIlJ8VA
# zSsNuuXxXiczzxFkXnob+olb2Dl0io5KiKbMpS39DtYfpUHJbSxqvnAa+Ci8reoV
# p3ApKHNFhwSpOQcfbOKnl7veN7M8fHb61piokbnEnN0MStnWcyLFGNoezcqlyyZl
# i7GwhF8Fg4m8AUbKZMZG/k+7Cw2mz0RyHUBqyrzgf9j/zE3cZCPg/cyIOfyLNQEM
# K5ch8diTf1uqdoCYVtSIJvL5Zam7N2TigMrP+xbCueyhDva4QZUQ3v6TLD34dKjm
# LyXxmDViaP21SAOlVQaMB26gvIdDteqScqZL2QlIEqTiiQQODQh3ot4otDAfV7hp
# V5PJRjBwFffCDukslBa9HudrZIau2X/bdgZBO52ZY6vKHH2WdTsoEZX9o2/PS1Ol
# yy5ywr5xkUoMSRYH+hQVWu3K6fo0Pmlhk2PQKBG6nmCtUAKr8CBv4Q4YsIP7MS0Y
# 2ini18q+xhvrjbns0n1esweCkKJvvpZPfhE+YIEHLEtSQfEernMLJg27QgVcC3UB
# WJzDXgz5zMtghUzs07JWkV1wHUH0yImKTul5KKLRdNF2Xn9X8qxxNoIEXPcwggdx
# MIIFWaADAgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3DQEBCwUAMIGI
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYDVQQDEylN
# aWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0yMTA5
# MzAxODIyMjVaFw0zMDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
# EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
# ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBD
# QSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA5OGmTOe0ciEL
# eaLL1yR5vQ7VgtP97pwHB9KpbE51yMo1V/YBf2xK4OK9uT4XYDP/XE/HZveVU3Fa
# 4n5KWv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTzxXb1hlDcwUTIcVxR
# MTegCjhuje3XD9gmU3w5YQJ6xKr9cmmvHaus9ja+NSZk2pg7uhp7M62AW36MEByd
# Uv626GIl3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3KNi1wjjHINSi9
# 47SHJMPgyY9+tVSP3PoFVZhtaDuaRr3tpK56KTesy+uDRedGbsoy1cCGMFxPLOJi
# ss254o2I5JasAUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF803RKJ1v2lIH1+
# /NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHovwUDo9Fzpk03dJQcNIIP8BDyt0cY
# 7afomXw/TNuvXsLz1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahhaYQFzymeiXtco
# dgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8wdJGUlNi5UPkLiWHzNgY1GIRH
# 29wb0f2y1BzFa/ZcUlFdEtsluq9QBXpsxREdcu+N+VLEhReTwDwV2xo3xwgVGD94
# q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0wggHZMBIGCSsGAQQBgjcV
# AQQFAgMBAAEwIwYJKwYBBAGCNxUCBBYEFCqnUv5kxJq+gpE8RjUpzxD/LwTuMB0G
# A1UdDgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAEVTBTMFEGDCsGAQQB
# gjdMg30BATBBMD8GCCsGAQUFBwIBFjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
# cGtpb3BzL0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYIKwYBBQUHAwgw
# GQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB
# /wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQwVgYDVR0f
# BE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJv
# ZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEBBE4w
# TDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0
# cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcNAQELBQADggIB
# AJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEGk5c9MTO1OdfCcTY/2mRs
# fNB1OW27DzHkwo/7bNGhlBgi7ulmZzpTTd2YurYeeNg2LpypglYAA7AFvonoaeC6
# Ce5732pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OOPcbzaN9l9qRWqveV
# tihVJ9AkvUCgvxm2EhIRXT0n4ECWOKz3+SmJw7wXsFSFQrP8DJ6LGYnn8AtqgcKB
# GUIZUnWKNsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3mSj5mO0+7hvoy
# GtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSwethQ/gpY3UA8x1RtnWN0SCyxTkctwRQE
# cb9k+SS+c23Kjgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxkoJLo4S5pu+yFU
# a2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFEfnyhYWxz/gq77EFmPWn9y8FBSX5+
# k77L+DvktxW/tM4+pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC4822rpM+Zv/Cuk0
# +CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7tfqAxM328y+l7vzhwRNGQ8cir
# Ooo6CGJ/2XBjU02N7oJtpQUQwXEGahC0HVUzWLOhcGbyoYICzjCCAjcCAQEwgfih
# gdCkgc0wgcoxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
# VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAj
# BgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsTHVRo
# YWxlcyBUU1MgRVNOOkU1QTYtRTI3Qy01OTJFMSUwIwYDVQQDExxNaWNyb3NvZnQg
# VGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQDRj4LIt7MaBUdYU2Yo
# jUu4T+Fjq6CBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
# dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
# YXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMA0G
# CSqGSIb3DQEBBQUAAgUA5d8vuTAiGA8yMDIyMDMxOTAwMjAwOVoYDzIwMjIwMzIw
# MDAyMDA5WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDl3y+5AgEAMAoCAQACAiQK
# AgH/MAcCAQACAhHdMAoCBQDl4IE5AgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisG
# AQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQEFBQAD
# gYEAZOG6Keh1n7Gv95sXdbJufsTAkHz4GMWFxZfI3J2Ym/7yHA/pvRZno3TfeWpl
# Y79vmoBR/Amsd6KWSVgPDNmECF7mO17gFvEastmXdYCSD0jAIW1KQqNpSegd+O/g
# ptY/9mbBCyxzuRSFLYTm7hi20ESdilarjBX0c7yDAdukfm0xggQNMIIECQIBATCB
# kzB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
# UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
# Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAZW3/A3W4zcxJQAB
# AAABlTANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJ
# EAEEMC8GCSqGSIb3DQEJBDEiBCDrpz802O7LbHh7tneo0fOxWnJxjkicoMH+g7NX
# JpDZ9zCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EIFzmS+GNkAt7aaEjP9B3
# uR5U6YD9wLV3MplPjJssSQLHMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
# UENBIDIwMTACEzMAAAGVt/wN1uM3MSUAAQAAAZUwIgQgFanpiIcZJRbt0Ee4Iszw
# 2LTclVr42qvkM1QCUq6Rlw8wDQYJKoZIhvcNAQELBQAEggIAWUSuUs+0vCYNLo/g
# +cJNZVutAkqrOJZ8lfMgnbEjzA7jO6kiLAO4+ByMHvT0DzeS4pVYnqww1StzZwnV
# 5LgpXMN6msXGhw0LwBXDv7aIgaI2r/DrujdkqC+ZT9600Ft+zKQnwnu0rFRfI8AR
# uZ7/dDx0U5KTuEVmnxD1GVyYQRqOOXuWSnjkSPBsNuf0lZoo/T5yQCmaWfj/xEXd
# 9zYL0RbHVMg4zL+AccakaxXc8Gr1aGjKTDuqzDMyXTjhqZ1oc+c7hUcFfEZLFyN5
# 0dbW2KdbYpigh1HybOt4Omq01rKhNNcUvDvqR1pl0l1syxvLgd32d57RdubIEXIO
# 02RE+NMe/cxV9r+iPFwLDvV+aOcKWEqB67SACrHv0xCzXHVWV7ROxCITxPIbyFcI
# e6BRCpLKiNFIQdaFC1fXwvBgP9bNgFMfYs8rF0KgDSazxXEgzmv7FnzYvOsGjYxN
# t2DlZH7da5X5h28gCuhtfBpt8aYKxSyEuqze2Ghkb4H6Q/OM8RkuT/bkENYoD9TK
# 9MmCsR1gFFL94a0FzhdZN4lVbMVFy6JwcxLkD6q9FiYz4wKak1Cc0I+GitL6SOaw
# NPNHL8iitph56TOaqo7eDHT+ohKH9TIvo1qomqI4pHtElJkisf+7IjIMcOF4x4Y+
# p/4yinLP7qHtfMLH5mQOuav1j6g=
# SIG # End signature block
